import sys

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class SiteprefsConfig(AppConfig):
    """The default siteprefs configuration."""

    name = 'siteprefs'
    verbose_name = _('Site Preferences')

    def ready(self):

        # Shouldn't try to autodiscover in test as
        # DB probably won't be initialized in the moment.
        if 'test' in sys.argv[0]:
            return

        from .toolbox import autodiscover_siteprefs
        autodiscover_siteprefs()



import os
from setuptools import setup
from siteprefs import VERSION

f = open(os.path.join(os.path.dirname(__file__), 'README.rst'))
readme = f.read()
f.close()

setup(
    name='django-siteprefs',
    version='.'.join(map(str, VERSION)),
    url='http://github.com/idlesign/django-siteprefs',

    description='Reusable app for Django introducing site preferences system',
    long_description=readme,
    license='BSD 3-Clause License',

    author='Igor `idle sign` Starikov',
    author_email='idlesign@yandex.ru',

    packages=['siteprefs'],
    include_package_data=True,
    zip_safe=False,

    install_requires=['django-etc >= 0.9.1'],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
